unit Unit9;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics, Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VclTee.TeeGDIPlus,
  Vcl.StdCtrls, VclTee.TeEngine, Vcl.ExtCtrls, VclTee.TeeProcs, VclTee.Chart, VclTee.Series, VclTee.TeePolar, VclTee.TeeLisB, Vcl.Buttons, VclTee.TeeEdiGrad,
  Vcl.Imaging.jpeg, VclTee.TeePoin3, VclTee.TeeTools, VclTee.TeeSurfa, VclTee.TeeComma, Data.DB, Data.Win.ADODB, Vcl.ComCtrls, Vcl.ImgList, VclTee.TeCanvas;

type
  TZoomSubChart = record
    ClickedIn: boolean;
    SubChartRect, ZoomRect: TRect;
  end;

  TForm1 = class(TForm)
    ButtonExit: TButton;
    Panel1: TPanel;
    TheChart: TChart;
    TeeCommander1: TTeeCommander;
    Series1: TLineSeries;
    Series2: TLineSeries;
    Series3: TPointSeries;
    NearestPointFunc: TNearestTool;
    procedure FormCreate(Sender: TObject);
    procedure ButtonExitClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure TheChartMouseDown(Sender: TObject; Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
    procedure TheChartMouseUp(Sender: TObject; Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
    procedure TheChartZoom(Sender: TObject);
  private
    { Private declarations }
    ZoomSubChart: TZoomSubChart;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

uses
  myUnit;

procedure TForm1.FormCreate(Sender: TObject);
begin
  with TheChart do
    begin
      if SeriesCount > 0 then
        FreeAllSeries();
      SeriesList.Clear;
      CustomAxes.Clear;
      CustomAxes.Add;
      CustomAxes[0].Horizontal := true;
      CustomAxes.Add;
      CustomAxes[1].Horizontal := false;
      Title.Visible := false;
      Foot.Text.Text := 'Test';

      with TopAxis do
        begin
          Title.Caption := 'Top Axis';
          Inverted := false;
        end;
      with LeftAxis do
        begin
          Title.Caption := 'Left Axis';
          Inverted := true;
        end;
      with CustomAxes[0] do
        begin
          Title.Caption := 'Custom HorizAxis';
          Inverted := false;
        end;
      with CustomAxes[1] do
        begin
          Title.Caption := 'Custom VertAxis';
          Inverted := false;
        end;
      GraphSetting_Chart_2D(TheChart); { to set the Chart and axes properties }

      with AddSeries(TLineSeries) as TLineSeries do
        begin
          Title := 'Main Chart'; { Curves based on Top and Left Axes }
          HorizAxis := aTopAxis;
          VertAxis := aLeftAxis;
        end;
      Series[SeriesCount - 1].AddXY(100, 1000, '', clTeeColor);
      Series[SeriesCount - 1].AddXY(3000, 5000, '', clTeeColor);

      with TheChart.AddSeries(TLineSeries) as TLineSeries do
        begin
          Title := 'Sub Chart'; { Curves based on CustomAxes }
          CustomHorizAxis := CustomAxes[0];
          CustomVertAxis := CustomAxes[1];
        end;
      Series[SeriesCount - 1].AddXY(300, 600, '', clTeeColor);
      Series[SeriesCount - 1].AddXY(500, 400, '', clTeeColor)
    end;

  TheChart.Draw;
end;

procedure TForm1.FormShow(Sender: TObject);
begin
  MakeIsoAxis(TheChart.Series[0]);
  SubChartSizeAndPostion(TheChart); { Place the SubChart at the TopRight corner of the MainChart, and the Height and Width are calculated automatically }
end;

procedure TForm1.TheChartMouseDown(Sender: TObject; Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  with ZoomSubChart do
    begin
      with SubChartRect do
        begin
          with TheChart.CustomAxes[0] do
            begin
              Left := CalcXPosValue(Minimum);
              Right := CalcXPosValue(Maximum);
            end;
          with TheChart.CustomAxes[1] do
            begin
              Top := CalcYPosValue(Maximum);
              Bottom := CalcYPosValue(Minimum);
            end;
        end;
      with ZoomRect do
        begin
          Left := X;
          Top := Y;
        end;
      ClickedIn := PointInRect(SubChartRect, X, Y);
    end;
end;

procedure TForm1.TheChartMouseUp(Sender: TObject; Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  with ZoomSubChart do
    begin
      with ZoomRect do
        begin
          Right := X;
          Bottom := Y;
        end;
      ClickedIn := ClickedIn or PointInRect(SubChartRect, X, Y);
      with ZoomRect do
        ClickedIn := ClickedIn and ((Right > Left) and (Bottom > Top));
    end;
end;

procedure TForm1.TheChartZoom(Sender: TObject);
begin
  inherited;
  if (TheChart.CustomAxes.Count > 0) and ZoomSubChart.ClickedIn then
    begin
      with TheChart.CustomAxes[0], ZoomSubChart.ZoomRect do
        SetMinMax(CalcPosPoint(Left), CalcPosPoint(Right));
      with TheChart.CustomAxes[1], ZoomSubChart.ZoomRect do
        SetMinMax(CalcPosPoint(Bottom), CalcPosPoint(Top));
      TheChart.Draw;
    end;
end;

procedure TForm1.ButtonExitClick(Sender: TObject);
begin
  Close;
end;

end.
