unit myUnit;

{$I TeeDefs.inc}

interface

uses
{$IFNDEF LINUX}
  Windows, Messages,
{$ENDIF}
  SysUtils, Classes,
{$IFDEF CLX}
  QGraphics, QControls, QForms, QDialogs, QExtCtrls, QStdCtrls,
{$ELSE}
  Graphics, Controls, Forms, Dialogs, ExtCtrls, StdCtrls,
{$ENDIF}
  VclTee.TeeProcs, VclTee.TeEngine, VclTee.Chart, VclTee.Series, VclTee.TeCanvas;

const
  ChartFontName = 'Arial';
  TitleFontSize = 10;
  AxisTitleFontSize = 8;
  AxisLabelFontSize = 6;

procedure GraphSetting_Chart_2D(var aChart: TChart);
procedure MakeIsoAxis(Vertical, Horizontal: TChartAxis); overload;
procedure MakeIsoAxis(Series: TChartSeries); overload;
procedure SubChartSizeAndPostion(TheChart: TChart);

implementation

procedure GraphSetting_Chart_2D(var aChart: TChart);
var
  i: integer;
  procedure GraphSetting_ChartAxis(aAxis: TChartAxis);
  begin
    with aAxis do
      begin
        MinimumRound := true;
        MaximumRound := true;
        Axis.Width := 2;
        Axis.Color := clBlack;
        Title.Font.Name := ChartFontName;
        Title.Font.Size := AxisTitleFontSize;
        Title.Font.Style := [];
        LabelsSeparation := 10;
        LabelsFont.Name := ChartFontName;
        LabelsFont.Size := AxisLabelFontSize;
        LabelsFont.Style := [];
        MinorTickCount := 3;
        PositionUnits := muPercent;
        AxisValuesFormat := '#,##0.###';
      end;
  end;

begin
  with aChart do
    begin
      View3D := false;
      View3DWalls := false;
      Chart3DPercent := 0;
      Aspect.Rotation := 360;
      Aspect.Elevation := 360;
      Aspect.Perspective := 0;
      Gradient.Visible := false;
      Shadow.Visible := false;
      Walls.Visible := true;
      Walls.Left.Visible := false;
      Walls.Right.Visible := false;
      Walls.Bottom.Visible := false;
      Walls.Back.Visible := true;
      Walls.Back.Frame.Width := 2;
      Walls.Back.Frame.Color := clBlack;
      Walls.Back.Color := Color;
      Walls.Back.Transparent := false;
      Walls.Back.Gradient.Visible := false;
      BevelInner := bvNone;
      BevelOuter := bvNone;
      BackColor := clWhite;
      MarginUnits := muPercent;
      MarginTop := 4;
      MarginBottom := 4;
      MarginLeft := 3;
      MarginRight := 3;
      DepthAxis.Visible := false;
      DepthTopAxis.Visible := false;
      DepthAxis.SetMinMax(0, 0);
      DepthTopAxis.SetMinMax(0, 0);
      Title.Visible := false;
      Title.Font.Name := ChartFontName;
      Title.Font.Size := TitleFontSize;
      Title.Font.Style := [fsBold];
      Foot.Visible := true;
      Foot.Font.Name := ChartFontName;
      Foot.Font.Size := TitleFontSize;
      Foot.Font.Style := [fsBold];
      Legend.FontSeriesColor := true;
      Legend.Font.Name := ChartFontName;
      Legend.Font.Size := AxisLabelFontSize;
      Legend.Font.Style := [];
      for i := 0 to Axes.Count - 1 do
        GraphSetting_ChartAxis(Axes[i]);
      for i := 0 to CustomAxes.Count - 1 do
        GraphSetting_ChartAxis(CustomAxes[i]);
    end;
end;

procedure MakeIsoAxis(Vertical, Horizontal: TChartAxis);
var
  tmpX, tmpY, XRange, YRange, Offset, XYScreen: Double;
begin
  with Vertical.ParentChart do
    if (ChartHeight > 0) and (ChartWidth > 0) then
      begin
        With Horizontal do
          XRange := Maximum - Minimum;
        tmpX := (XRange / ChartWidth);

{$IFDEF CLX}
        XYScreen := 1024.0 / 768.0; // TODO
{$ELSE}
        XYScreen := 1.0 * (GetDeviceCaps(Canvas.Handle, HORZSIZE) / Screen.Width) / (GetDeviceCaps(Canvas.Handle, VERTSIZE) / Screen.Height);
{$ENDIF}
        With Vertical do
          YRange := Maximum - Minimum;
        tmpY := (YRange / ChartHeight) * XYScreen;

        if tmpX > tmpY then
          begin
            if tmpY <> 0 then
              begin
                Offset := ((YRange * tmpX / tmpY) - YRange) / 2.0;
                With Vertical do
                  SetMinMax(Minimum - Offset, Maximum + Offset);
              end;
          end
        else if tmpX < tmpY then
          begin
            if tmpX <> 0 then
              begin
                Offset := ((XRange * tmpY / tmpX) - XRange) / 2.0;
                With Horizontal do
                  SetMinMax(Minimum - Offset, Maximum + Offset);
              end;
          end;
      end;
end;

procedure MakeIsoAxis(Series: TChartSeries);
begin
  MakeIsoAxis(Series.GetVertAxis, Series.GetHorizAxis);
end;

procedure SubChartSizeAndPostion(TheChart: TChart);
var
  MainAxisSize, SubAxisSize: Real;
begin
  with TheChart.Series[0].GetHorizAxis do
    begin
      MainAxisSize := Maximum - Minimum;
      if Increment = 0 then
        Increment := CalcIncrement;
    end;
  with TheChart.CustomAxes[0] do
    begin
      AdjustMaxMin;
      Increment := TheChart.Series[0].GetHorizAxis.Increment; { the Increment and scale are the same with main chart HorizAxis. }
      if (Maximum - Minimum) < 2 * Increment then { the Minimum, Maximum and Increment are all zero. }
        begin
          Minimum := Int(Minimum / Increment) * Increment - Increment;
          Maximum := Int(Maximum / Increment) * Increment + Increment;
        end;
      SubAxisSize := Maximum - Minimum;
      StartPosition := 100 - SubAxisSize / MainAxisSize * 100;
      EndPosition := 100;
      TheChart.CustomAxes[1].PositionPercent := StartPosition;
    end;

  with TheChart.Series[0].GetVertAxis do
    begin
      MainAxisSize := Maximum - Minimum;
      if Increment = 0 then
        Increment := CalcIncrement;
    end;
  with TheChart.CustomAxes[1] do
    begin
      Increment := TheChart.Series[0].GetVertAxis.Increment; { the Increment and scale are the same with main chart VertAxis. }
      if (Maximum - Minimum) < 2 * Increment then
        begin
          Minimum := Int(Minimum / Increment) * Increment - Increment;
          Maximum := Int(Maximum / Increment) * Increment + Increment;
        end;
      SubAxisSize := Maximum - Minimum;
      StartPosition := 0;
      EndPosition := SubAxisSize / MainAxisSize * 100;
      TheChart.CustomAxes[0].PositionPercent := 100 - EndPosition;
    end;
end;

end.
